==> tinderbox-devel-3.4.r3%2C1.tbz: tinderbox/scripts/webui/core/TinderObject.php <==
<?php
#-
# Copyright (c) 2004-2005 FreeBSD GNOME Team <freebsd-gnome@FreeBSD.org>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
# $MCom: portstools/tinderbox/webui/core/TinderObject.php,v 1.5.2.1 2011/08/11 12:48:32 beat Exp $
#

    class TinderObject {
	public $_object_hash = array();
	public $_truth_array = array(
		"t" => "1",
		"f" => "0",
		"0" => "0",
		"1" => "1",
	);

	function TinderObject($object_hash, $attrs = array()) {
	    $this->_object_hash = $object_hash;

	    foreach ($attrs as $key => $value) {
		if (isset($this->_object_hash[$key])) {
		    $this->$key = $value;
		}
	    }
	}

	function toHashRef() {
	    $hashref = array();

	    foreach ($this->_object_hash as $key => $value) {
		$hashref[$key] = $value;
	    }

	    return $hashref;
	}

    }
?>

==> tinderbox-devel-4.0.0.b2_1%2C1.tbz: tinderbox/scripts/webui/core/TinderObject.php <==
<?php
#-
# Copyright (c) 2004-2005 FreeBSD GNOME Team <freebsd-gnome@FreeBSD.org>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
# $MCom: portstools/tinderbox/webui/core/TinderObject.php,v 1.7 2010/12/27 00:28:50 beat Exp $
#

class TinderObject {

	public $_object_hash = array();
	public $_truth_array = array(
		't' => '1',
		'f' => '0',
		'0' => '0',
		'1' => '1',
	);

	function TinderObject( $object_hash, $attrs = array() ) {
		$this->_object_hash = $object_hash;

		foreach ( $attrs as $key => $value ) {
			if ( isset( $this->_object_hash[$key] ) ) {
				$this->$key = $value;
			}
		}
	}

	function toHashRef() {
		$hashref = array();

		foreach ( $this->_object_hash as $key => $value ) {
			$hashref[$key] = $value;
		}

		return $hashref;
	}

}
?>
